@@ -28,21 +28,21 @@
 #' \itemize{
 #' \item {\strong{linetype:}} {default to 1}
 #' \item {\strong{color:}} {default to black}
-#' \item {\strong{size:}} {default to 1}
+#' \item {\strong{linewidth:}} {default to 1}
 #' }
 #'
 #' \strong{snd_line} is a list that contains:
 #' \itemize{
 #' \item {\strong{linetype:}} {default to 2}
 #' \item {\strong{color:}} {default to black}
-#' \item {\strong{size:}} {default to 1}
+#' \item {\strong{linewidth:}} {default to 1}
 #' }
 #'
 #' \strong{vline} is a list that contains:
 #' \itemize{
 #' \item {\strong{linetype:}} {default to 3}
 #' \item {\strong{color:}} {default to black}
-#' \item {\strong{size:}} {default to 1}
+#' \item {\strong{linewidth:}} {default to 1}
 #' }
 #'
 pmx_dens <- function(
@@ -68,11 +68,11 @@ pmx_dens <- function(
     )
   }
   assert_that(is_list(labels))
-  default_var_line <- list(linetype = 1, colour = "black", size = 1)
+  default_var_line <- list(linetype = 1, colour = "black", linewidth = 1)
   var_line <- l_left_join(default_var_line, var_line)
-  default_snd_line <- list(linetype = 2, colour = "black", size = 1)
+  default_snd_line <- list(linetype = 2, colour = "black", linewidth = 1)
   snd_line <- l_left_join(default_snd_line, snd_line)
-  default_vline <- list(linetype = 3, colour = "black", size = 1)
+  default_vline <- list(linetype = 3, colour = "black", linewidth = 1)
   vline <- l_left_join(default_vline, snd_line)
   labels$subtitle <- ""
   structure(list(
@@ -94,25 +94,7 @@ pmx_dens <- function(
 }
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-#' This function plot EBE versus covariates using qq plots
+#' This function plots EBE versus covariates using qq plots
 #'
 #' @param x eta_cov object
 #' @param dx data set
@@ -126,7 +108,6 @@ pmx_dens <- function(
 plot_pmx.pmx_dens <- function(x, dx, ...) {
   dx <- dx[!is.infinite(get(x$x))]
 
-
   with(x, {
     xrange <- c(-xlim, xlim)
 
@@ -136,32 +117,41 @@ plot_pmx.pmx_dens <- function(x, dx, ...) {
       do.call(geom_vline, params)
     }
 
+    p <- ggplot(dx,
+      aes(x=get(x))) +
+      geom_density(
+        aes(IWRES, colour="variable density", linetype="variable density"),
+        alpha=0.5,
+        show.legend=FALSE
+      ) +
+      stat_function(
+        data.frame(x = xrange),
+        fun=dnorm,
+        mapping=aes(x, linetype="normal density", colour="normal density")
+      ) +
+      scale_linetype_manual(
+        values=c(snd_line[["linetype"]], var_line[["linetype"]]),
+        guide="none"
+      ) +
+      scale_colour_manual(
+        values=c(snd_line[["colour"]], var_line[["colour"]]),
+        guide="none"
+      ) +
+      guides(
+        linetype=guide_legend(title=NULL, override.aes=list(linewidth=c(1,1))),
+        colour=guide_legend(title=NULL)
+      ) +
+      vline_layer
 
-    p <- ggplot(dx, aes(x = get(x), colour = "variable density")) +
-      geom_density(aes(IWRES, linetype = "variable density"), alpha = 0.5) +
-      stat_function(data.frame(x = xrange), 
-                    fun = dnorm,
-                    mapping = aes(x, colour = "normal density", linetype = "normal density")) +
-      scale_linetype_manual(values = c(snd_line$linetype, var_line$linetype),
-                            guide = "none") +
-      scale_colour_manual(values = c(snd_line$colour, var_line$colour),
-                          guide = guide_legend(override.aes = list(
-                            linetype = c(snd_line$linetype, var_line$linetype),
-                            size = c(1, 1)),
-                            title = NULL))+vline_layer
-
-    if (is.legend) { 
-      gp$is.legend <- is.legend
-      gp$legend.position <- "top"
+    if (is.legend) {
+      gp[["is.legend"]] <- is.legend
+      gp[["legend.position"]] <- "top"
     }
 
-
-
     if (!is.null(p)) p <- plot_pmx(gp, p)
 
-    p <- p +
-      coord_cartesian(xlim = xrange) +
-      theme(aspect.ratio = 1)
-    p
+    p +
+    coord_cartesian(xlim = xrange) +
+    theme(aspect.ratio = 1)
   })
 }
