@@ -14,7 +14,7 @@ pmx_theme <- function(...) {
       ## strip.background = element_rect( colour = NA),
       plot.title = element_text(size = 12),
       axis.text = element_text(size = 10),
-      plot.margin = unit(c(1, 1, 1, 1), "cm"),
+      #plot.margin = unit(c(1, 1, 1, 1), "cm"),
       legend.position = "none"
     ) %+replace%
     theme(...)
